@@ -28,11 +28,10 @@ def crop_resize(image, size, exact_size=False):
             if not exact_size:
                 return image
         else:
-            raise NotImplementedError
+            pass
+            # raise NotImplementedError
     elif size[1] > image.size[1]:
         raise NotImplementedError
-            
-    import pdb; pdb.set_trace()
     
     if crop:
         if image_ar > size_ar:
